==> odata-client-microsoft-dynamics-0.1.46-sources.jar: microsoft/dynamics/crm/complex/RetrieveTotalRecordCountResponse.java <==
package microsoft.dynamics.crm.complex;

import com.fasterxml.jackson.annotation.JacksonInject;
import com.fasterxml.jackson.annotation.JsonAnyGetter;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.ODataType;
import com.github.davidmoten.odata.client.UnmappedFields;
import com.github.davidmoten.odata.client.Util;
import com.github.davidmoten.odata.client.annotation.Property;
import com.github.davidmoten.odata.client.internal.ChangedFields;
import com.github.davidmoten.odata.client.internal.UnmappedFieldsImpl;

import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.StringBuilder;
import java.util.Optional;

@JsonPropertyOrder({
    "@odata.type", 
    "EntityRecordCountCollection"})
@JsonInclude(Include.NON_NULL)
public class RetrieveTotalRecordCountResponse implements ODataType {

    @JacksonInject
    @JsonIgnore
    protected ContextPath contextPath;

    @JacksonInject
    @JsonIgnore
    protected UnmappedFieldsImpl unmappedFields;

    @JsonProperty("@odata.type")
    protected String odataType;

    @JsonProperty("EntityRecordCountCollection")
    protected EntityRecordCountCollection entityRecordCountCollection;

    protected RetrieveTotalRecordCountResponse() {
    }

    @Override
    public String odataTypeName() {
        return "Microsoft.Dynamics.CRM.RetrieveTotalRecordCountResponse";
    }

    @Property(name="EntityRecordCountCollection")
    @JsonIgnore
    public Optional<EntityRecordCountCollection> getEntityRecordCountCollection() {
        return Optional.ofNullable(entityRecordCountCollection);
    }

    public RetrieveTotalRecordCountResponse withEntityRecordCountCollection(EntityRecordCountCollection entityRecordCountCollection) {
        RetrieveTotalRecordCountResponse _x = _copy();
        _x.odataType = Util.nvl(odataType, "Microsoft.Dynamics.CRM.RetrieveTotalRecordCountResponse");
        _x.entityRecordCountCollection = entityRecordCountCollection;
        return _x;
    }

    public RetrieveTotalRecordCountResponse withUnmappedField(String name, String value) {
        RetrieveTotalRecordCountResponse _x = _copy();
        _x.setUnmappedField(name, value);
        return _x;
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFieldsImpl();
        }
        unmappedFields.put(name, value);
    }

    @JsonAnyGetter
    private UnmappedFieldsImpl unmappedFields() {
        return unmappedFields == null ? UnmappedFieldsImpl.EMPTY : unmappedFields;
    }

    @Override
    public UnmappedFields getUnmappedFields() {
        return unmappedFields();
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        // do nothing;
    }

    /**
     * Returns a builder which is used to create a new
     * instance of this class (given that this class is immutable).
     *
     * @return a new Builder for this class
     */
    // Suffix used on builder factory method to differentiate the method
    // from static builder methods on superclasses
    public static Builder builder() {
        return new Builder();
    }

    public static final class Builder {
        private EntityRecordCountCollection entityRecordCountCollection;
        private ChangedFields changedFields = new ChangedFields();

        Builder() {
            // prevent instantiation
        }

        public Builder entityRecordCountCollection(EntityRecordCountCollection entityRecordCountCollection) {
            this.entityRecordCountCollection = entityRecordCountCollection;
            this.changedFields = changedFields.add("EntityRecordCountCollection");
            return this;
        }

        public RetrieveTotalRecordCountResponse build() {
            RetrieveTotalRecordCountResponse _x = new RetrieveTotalRecordCountResponse();
            _x.contextPath = null;
            _x.unmappedFields = new UnmappedFieldsImpl();
            _x.odataType = "Microsoft.Dynamics.CRM.RetrieveTotalRecordCountResponse";
            _x.entityRecordCountCollection = entityRecordCountCollection;
            return _x;
        }
    }

    private RetrieveTotalRecordCountResponse _copy() {
        RetrieveTotalRecordCountResponse _x = new RetrieveTotalRecordCountResponse();
        _x.contextPath = contextPath;
        _x.unmappedFields = unmappedFields.copy();
        _x.odataType = odataType;
        _x.entityRecordCountCollection = entityRecordCountCollection;
        return _x;
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("RetrieveTotalRecordCountResponse[");
        b.append("EntityRecordCountCollection=");
        b.append(this.entityRecordCountCollection);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }

}

==> odata-client-microsoft-dynamics-0.1.83-sources.jar: microsoft/dynamics/crm/complex/RetrieveTotalRecordCountResponse.java <==
package microsoft.dynamics.crm.complex;

import com.fasterxml.jackson.annotation.JacksonInject;
import com.fasterxml.jackson.annotation.JsonAnyGetter;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.ODataType;
import com.github.davidmoten.odata.client.UnmappedFields;
import com.github.davidmoten.odata.client.Util;
import com.github.davidmoten.odata.client.annotation.Property;
import com.github.davidmoten.odata.client.internal.ChangedFields;
import com.github.davidmoten.odata.client.internal.UnmappedFieldsImpl;

import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.StringBuilder;
import java.util.Optional;

@JsonPropertyOrder({
    "@odata.type", 
    "EntityRecordCountCollection"})
@JsonInclude(Include.NON_NULL)
public class RetrieveTotalRecordCountResponse implements ODataType {

    @JacksonInject
    @JsonIgnore
    protected ContextPath contextPath;

    @JacksonInject
    @JsonIgnore
    protected UnmappedFieldsImpl unmappedFields;

    @JsonProperty("@odata.type")
    protected String odataType;

    @JsonProperty("EntityRecordCountCollection")
    protected EntityRecordCountCollection entityRecordCountCollection;

    protected RetrieveTotalRecordCountResponse() {
    }

    @Override
    public String odataTypeName() {
        return "Microsoft.Dynamics.CRM.RetrieveTotalRecordCountResponse";
    }

    @Property(name="EntityRecordCountCollection")
    @JsonIgnore
    public Optional<EntityRecordCountCollection> getEntityRecordCountCollection() {
        return Optional.ofNullable(entityRecordCountCollection);
    }

    public RetrieveTotalRecordCountResponse withEntityRecordCountCollection(EntityRecordCountCollection entityRecordCountCollection) {
        RetrieveTotalRecordCountResponse _x = _copy();
        _x.odataType = Util.nvl(odataType, "Microsoft.Dynamics.CRM.RetrieveTotalRecordCountResponse");
        _x.entityRecordCountCollection = entityRecordCountCollection;
        return _x;
    }

    public RetrieveTotalRecordCountResponse withUnmappedField(String name, String value) {
        RetrieveTotalRecordCountResponse _x = _copy();
        _x.setUnmappedField(name, value);
        return _x;
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFieldsImpl();
        }
        unmappedFields.put(name, value);
    }

    @JsonAnyGetter
    private UnmappedFieldsImpl unmappedFields() {
        return unmappedFields == null ? UnmappedFieldsImpl.EMPTY : unmappedFields;
    }

    @Override
    public UnmappedFields getUnmappedFields() {
        return unmappedFields();
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        // do nothing;
    }

    /**
     * Returns a builder which is used to create a new
     * instance of this class (given that this class is immutable).
     *
     * @return a new Builder for this class
     */
    // Suffix used on builder factory method to differentiate the method
    // from static builder methods on superclasses
    public static Builder builder() {
        return new Builder();
    }

    public static final class Builder {
        private EntityRecordCountCollection entityRecordCountCollection;
        private ChangedFields changedFields = ChangedFields.EMPTY;

        Builder() {
            // prevent instantiation
        }

        public Builder entityRecordCountCollection(EntityRecordCountCollection entityRecordCountCollection) {
            this.entityRecordCountCollection = entityRecordCountCollection;
            this.changedFields = changedFields.add("EntityRecordCountCollection");
            return this;
        }

        public RetrieveTotalRecordCountResponse build() {
            RetrieveTotalRecordCountResponse _x = new RetrieveTotalRecordCountResponse();
            _x.contextPath = null;
            _x.unmappedFields = new UnmappedFieldsImpl();
            _x.odataType = "Microsoft.Dynamics.CRM.RetrieveTotalRecordCountResponse";
            _x.entityRecordCountCollection = entityRecordCountCollection;
            return _x;
        }
    }

    private RetrieveTotalRecordCountResponse _copy() {
        RetrieveTotalRecordCountResponse _x = new RetrieveTotalRecordCountResponse();
        _x.contextPath = contextPath;
        _x.unmappedFields = unmappedFields.copy();
        _x.odataType = odataType;
        _x.entityRecordCountCollection = entityRecordCountCollection;
        return _x;
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("RetrieveTotalRecordCountResponse[");
        b.append("EntityRecordCountCollection=");
        b.append(this.entityRecordCountCollection);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }

}
